diff --git a/web/pgadmin/static/js/sqleditor/new_connection_dialog.js b/web/pgadmin/static/js/sqleditor/new_connection_dialog.js
index 3fcd374..a674f2c 100644
--- a/web/pgadmin/static/js/sqleditor/new_connection_dialog.js
+++ b/web/pgadmin/static/js/sqleditor/new_connection_dialog.js
@@ -230,6 +230,8 @@ let NewConnectionDialog = {
                   'user': newConnCollectionModel['user'],
                   'role': newConnCollectionModel['role'],
                   'password': response.password,
+                  'server_name': response.server_name,
+                  'database_name': selected_database_name,
                 };
                 handler.gridView.on_change_connection(connection_details, self);
               }
diff --git a/web/pgadmin/tools/datagrid/templates/datagrid/index.html b/web/pgadmin/tools/datagrid/templates/datagrid/index.html
index 4970027..feedc63 100644
--- a/web/pgadmin/tools/datagrid/templates/datagrid/index.html
+++ b/web/pgadmin/tools/datagrid/templates/datagrid/index.html
@@ -418,11 +418,13 @@
                 </i>
             </div>
             <div class="connection-info btn-group mr-1" role="group" aria-label="">
-                <div class="editor-title" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false"
-                     style="background-color: {% if fgcolor %}{{ bgcolor or '#FFFFFF' }}{% endif %}; color: {% if fgcolor %}{{ fgcolor }}{% endif %};">&nbsp;
+                <div class="connection-data" data-toggle="dropdown">
+                    <div class="editor-title" aria-haspopup="true" aria-expanded="false"
+                         style="background-color: {% if fgcolor %}{{ bgcolor or '#FFFFFF' }}{% endif %}; color: {% if fgcolor %}{{ fgcolor }}{% endif %};">&nbsp;
+                    </div>
+                    <span class="conn-info-dd dropdown-toggle dropdown-toggle-split"
+                    aria-haspopup="true" aria-expanded="false"></span>
                 </div>
-                <span class="conn-info-dd dropdown-toggle dropdown-toggle-split"
-                data-toggle="dropdown" aria-haspopup="true" aria-expanded="false"></span>
                 <ul class="dropdown-menu" id="connections-list">
                 </ul>
             </div>
diff --git a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
index 4ef4b8f..600a644 100644
--- a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
+++ b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
@@ -182,7 +182,7 @@ define('tools.querytool', [
         });
       } else {
         $('.conn-info-dd').hide();
-        $('.editor-title').css({pointerEvents: 'none'});
+        $('.connection-data').css({pointerEvents: 'none', cursor: 'arrow'});
       }
     },
 
@@ -2122,8 +2122,20 @@ define('tools.querytool', [
       let title = this.$el.find('.editor-title').html();
       if(connection_details['title'] != title) {
         var self = this;
+        var loadingDiv = null;
+        var msgDiv = null;
+        if(ref){
+          loadingDiv = $('#show_filter_progress');
+          loadingDiv.removeClass('d-none');
+          msgDiv = loadingDiv.find('.sql-editor-busy-text');
+          msgDiv.text('Connecting to database...');
+        } else{
+          loadingDiv = $('#fetching_data');
+          loadingDiv.removeClass('d-none');
+          msgDiv = loadingDiv.find('.sql-editor-busy-text');
+        }
+
         $.ajax({
-          async: false,
           url: url_for('datagrid.update_query_tool_connection', {
             'trans_id': self.transId,
             'sgid': connection_details['server_group'],
@@ -2148,7 +2160,8 @@ define('tools.querytool', [
               };
               self.set_editor_title(self.handler.url_params.title);
               self.handler.setTitle(self.handler.url_params.title);
-              alertify.success('connected successfully');
+              let success_msg = connection_details['server_name'] + '/' + connection_details['database_name']+ '- Database connected';
+              alertify.success(success_msg);
               if(ref){
                 let connection_data = {
                   'server_group': self.handler.url_params.sgid,
@@ -2159,15 +2172,21 @@ define('tools.querytool', [
                   'role': connection_details['role'],
                   'password': connection_details['password'],
                   'is_allow_new_connection': true,
+                  'database_name': connection_details['database_name'],
+                  'server_name': connection_details['server_name'],
                 };
                 self.connection_list.unshift(connection_data);
                 self.render_connection(self.connection_list);
+                loadingDiv.addClass('d-none');
                 ref.close();
+              } else {
+                loadingDiv.addClass('d-none');
               }
             }
             return true;
           })
           .fail(function(xhr) {
+            loadingDiv.addClass('d-none');
             if(xhr.status == 428) {
               alertify.connectServer('Connect to server', xhr.responseJSON.result, connection_details['server'], false);
             } else {
@@ -2526,6 +2545,8 @@ define('tools.querytool', [
             'role': null,
             'title': _.unescape(url_params.title),
             'is_allow_new_connection': false,
+            'database_name': url_params.title.split('/')[0],
+            'server_name': url_params.title.split('@')[1],
           };
           self.gridView.connection_list.unshift(connection_data);
           self.gridView.render_connection(self.gridView.connection_list);
diff --git a/web/pgadmin/tools/sqleditor/static/scss/_sqleditor.scss b/web/pgadmin/tools/sqleditor/static/scss/_sqleditor.scss
index 53f2449..7fc576a 100644
--- a/web/pgadmin/tools/sqleditor/static/scss/_sqleditor.scss
+++ b/web/pgadmin/tools/sqleditor/static/scss/_sqleditor.scss
@@ -43,6 +43,12 @@
   cursor: pointer;
 }
 
+.connection-data {
+  display: inherit;
+  cursor: pointer;
+  width: auto;
+}
+
 
 #editor-panel {
   z-index: 0;
